@@ -1,20 +1,22 @@
-/// Backported version of the [`Chain`](std::error::Chain) struct,
-/// to versions of Rust lacking it.
+/// An iterator over an Error and its sources.
+///
+/// If you want to omit the initial error and only process its sources, use `skip(1)`.
 ///
 /// Can be created via [`ErrorCompat::iter_chain`][crate::ErrorCompat::iter_chain].
+#[derive(Debug, Clone)]
 pub struct ChainCompat<'a> {
-    inner: Option<&'a dyn std::error::Error>,
+    inner: Option<&'a dyn crate::Error>,
 }
 
 impl<'a> ChainCompat<'a> {
     /// Creates a new error chain iterator.
-    pub fn new(error: &'a dyn std::error::Error) -> Self {
+    pub fn new(error: &'a dyn crate::Error) -> Self {
         ChainCompat { inner: Some(error) }
     }
 }
 
 impl<'a> Iterator for ChainCompat<'a> {
-    type Item = &'a dyn std::error::Error;
+    type Item = &'a dyn crate::Error;
 
     fn next(&mut self) -> Option<Self::Item> {
         match self.inner {
